function [t,y] = lietrotter(psi1,psi2,y0,tspan,N)
% Single step method based on Lie-Trotter splitting
% psi1 and psi2 must be function of type @(h,y)
% y0: initial value
% tspan: [0,T]
% N: number of timesteps
% t: meshpoints of timegrid
% y: solution at meshpoints of timegrid

t = [tspan(1)];
y = [y0];
h = (tspan(2)-tspan(1))/N;

for k=1:N
  y0 = psi1(h,y0);
  y0 = psi2(h,y0);
  y = [y;y0];
  t = [t;k*h];
end
